# Welcome to Logbook

<img src="https://raw.githubusercontent.com/getlogbook/logbook/master/docs/_static/logbook-logo.png" width="300">



|                    |                             |
|--------------------|-----------------------------|
| Travis             | [![Build Status][ti]][tl]   |
| AppVeyor           | [![Build Status][ai]][al]   |
| Supported Versions | ![Supported Versions][vi]   |
| Latest Version     | [![Latest Version][pi]][pl] |
| Test Coverage      | [![Test Coverage][ci]][cl]  |


Logbook is a nice logging replacement.

It should be easy to setup, use and configure and support web applications :)

For more information: http://logbook.readthedocs.org

[ti]: https://secure.travis-ci.org/getlogbook/logbook.svg?branch=master
[tl]: https://travis-ci.org/getlogbook/logbook
[ai]: https://ci.appveyor.com/api/projects/status/quu99exa26e06npp?svg=true
[vi]: https://img.shields.io/badge/python-2.7%2C3.5%2C3.6%2C3.7-green.svg
[di]: https://img.shields.io/pypi/dm/logbook.svg
[al]: https://ci.appveyor.com/project/vmalloc/logbook
[pi]: https://img.shields.io/pypi/v/logbook.svg
[pl]: https://pypi.org/pypi/Logbook
[ci]: https://coveralls.io/repos/getlogbook/logbook/badge.svg?branch=master&service=github
[cl]: https://coveralls.io/github/getlogbook/logbook?branch=master
